@@ -17,15 +17,12 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 import chess
+import collections
 import struct
 import os
 import mmap
 import random
 
-try:
-    import backport_collections as collections
-except ImportError:
-    import collections
 
 ENTRY_STRUCT = struct.Struct(">QHHI")
 
