@@ -570,7 +570,7 @@ class ThreeCheckBoard(chess.Board):
     def is_variant_win(self):
         return self.remaining_checks[self.turn] <= 0 and self.remaining_checks[not self.turn] > 0
 
-    def is_irreversible(move):
+    def is_irreversible(self, move):
         if super(ThreeCheckBoard, self).is_irreversible(move):
             return True
 
@@ -581,7 +581,7 @@ class ThreeCheckBoard(chess.Board):
 
     def _transposition_key(self):
         return (super(ThreeCheckBoard, self)._transposition_key(),
-                self.remaining_checks[WHITE], self.remaining_checks[BLACK])
+                self.remaining_checks[chess.WHITE], self.remaining_checks[chess.BLACK])
 
     def copy(self, stack=True):
         board = super(ThreeCheckBoard, self).copy(stack=stack)
